If wasm-test feature of concordium-std is enabled ignore the item,
this usually happens when executing tests with cargo-concordium utility.
Otherwise this is equivalent to #[cfg(not(test))]. Use as a dual to
#[concordium_cfg_test].
Derive the conversion of enums that represent error types into the Reject
struct which can be used as the error type of init and receive functions.
Creating custom enums for error types can provide meaningful error messages
to the user of the smart contract.
A helper macro to derive both the Serial and Deserial traits.
[derive(Serialize)] is equivalent to [derive(Serial, Deserial)], see
documentation of the latter two for details and options:
derive(Serial),
derive(Deserial).